'''
Created by auto_sdk on 2022.01.17
'''
from dingtalk.api.base import RestApi
class OapiV2UserGetbymobileRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.mobile = None
		self.support_exclusive_account_search = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.v2.user.getbymobile'



'''
Created by auto_sdk on 2020.04.09
'''
from dingtalk.api.base import RestApi
class OapiAttendanceGroupUsersRemoveRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.group_key = None
		self.op_userid = None
		self.user_id_list = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.attendance.group.users.remove'



'''
Created by auto_sdk on 2020.08.19
'''
from dingtalk.api.base import RestApi
class OapiAtsChannelAccountAddRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.biz_code = None
		self.channel_user_identify = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.ats.channel.account.add'



'''
Created by auto_sdk on 2020.01.09
'''
from dingtalk.api.base import RestApi
class OapiEduFaceSearchRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.class_id = None
		self.height = None
		self.synchronous = None
		self.url = None
		self.userid = None
		self.width = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.edu.face.search'



'''
Created by auto_sdk on 2021.02.26
'''
from dingtalk.api.base import RestApi
class OapiImChatScencegroupRobotQueryRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.open_conversation_id = None
		self.robot_code = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.im.chat.scencegroup.robot.query'



'''
Created by auto_sdk on 2020.05.18
'''
from dingtalk.api.base import RestApi
class OapiDepartmentUpdateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.autoAddUser = None
		self.createDeptGroup = None
		self.deptHiding = None
		self.deptManagerUseridList = None
		self.deptPerimits = None
		self.deptPermits = None
		self.groupContainHiddenDept = None
		self.groupContainOuterDept = None
		self.groupContainSubDept = None
		self.id = None
		self.lang = None
		self.name = None
		self.order = None
		self.orgDeptOwner = None
		self.outerDept = None
		self.outerDeptOnlySelf = None
		self.outerPermitDepts = None
		self.outerPermitUsers = None
		self.parentid = None
		self.sourceIdentifier = None
		self.userPerimits = None
		self.userPermits = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.department.update'



'''
Created by auto_sdk on 2021.01.22
'''
from dingtalk.api.base import RestApi
class OapiImChatServicegroupDisbandRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.chat_id = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.im.chat.servicegroup.disband'



'''
Created by auto_sdk on 2022.04.28
'''
from dingtalk.api.base import RestApi
class OapiFinanceFaceVerificationInitRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.bio_info = None
		self.cert_name = None
		self.id_card_no = None
		self.scene = None
		self.user_mobile = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.finance.faceVerification.init'



'''
Created by auto_sdk on 2021.03.22
'''
from dingtalk.api.base import RestApi
class OapiKacOpenliveRecordListRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.author_user_id = None
		self.begin_time = None
		self.end_time = None
		self.page_size = None
		self.page_start = None
		self.status = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.kac.openlive.record.list'



# -*- coding: utf-8 -*-
'''
Created on 2018-9-17

@author: xiaoxuan.lp
'''

try: import http.client
except ImportError:
    import http.client as httplib
import urllib.request, urllib.parse, urllib.error
import time
import hashlib
import json
import dingtalk
import itertools
import mimetypes
import hmac
import base64

'''
定义一些系统变量
'''

SYSTEM_GENERATE_VERSION = "taobao-sdk-python-dynamicVersionNo"

P_APPKEY = "app_key"
P_API = "method"
P_ACCESS_TOKEN = "access_token"
P_VERSION = "v"
P_FORMAT = "format"
P_TIMESTAMP = "timestamp"
P_SIGN = "sign"
P_SIGN_METHOD = "sign_method"
P_PARTNER_ID = "partner_id"

P_CODE = 'errcode'
P_MSG = 'errmsg'

def sign(secret, parameters):
    #===========================================================================
    # '''签名方法
    # @param secret: 签名需要的密钥
    # @param parameters: 支持字典和string两种
    # '''
    #===========================================================================
    # 如果parameters 是字典类的话
    if hasattr(parameters, "items"):
        keys = list(parameters.keys())
        keys.sort()
        
        parameters = "%s%s%s" % (secret,
            str().join('%s%s' % (key, parameters[key]) for key in keys),
            secret)
    sign = hashlib.md5(parameters.encode("utf-8")).hexdigest().upper()
    return sign

def mixStr(pstr):
    if(isinstance(pstr, str)):
        return pstr
    elif(isinstance(pstr, str)):
        return pstr.encode('utf-8')
    else:
        return str(pstr)
    
class FileItem(object):
    def __init__(self,filename=None,content=None):
        self.filename = filename
        self.content = content

class MultiPartForm(object):
    """Accumulate the data to be used when posting a form."""

    def __init__(self):
        self.form_fields = []
        self.files = []
        self.boundary = "PYTHON_SDK_BOUNDARY"
        return
    
    def get_content_type(self):
        return 'multipart/form-data;charset=UTF-8; boundary=%s' % self.boundary

    def add_field(self, name, value):
        """Add a simple field to the form data."""
        self.form_fields.append((name, str(value)))
        return

    def add_file(self, fieldname, filename, fileHandle, mimetype=None):
        """Add a file to be uploaded."""
        body = fileHandle.read()
        if mimetype is None:
            mimetype = mimetypes.guess_type(filename)[0] or 'application/octet-stream'
        self.files.append((mixStr(fieldname), mixStr(filename), mixStr(mimetype), mixStr(body)))
        return
    
    def __str__(self):
        """Return a string representing the form data, including attached files."""
        # Build a list of lists, each containing "lines" of the
        # request.  Each part is separated by a boundary string.
        # Once the list is built, return a string where each
        # line is separated by '\r\n'.  
        parts = []
        part_boundary = '--' + self.boundary
        
        # Add the form fields
        parts.extend(
            [ part_boundary,
              'Content-Disposition: form-data; name="%s"' % name,
              'Content-Type: text/plain; charset=UTF-8',
              '',
              value,
            ]
            for name, value in self.form_fields
            )
        
        # Add the files to upload
        parts.extend(
            [ part_boundary,
              'Content-Disposition: form-data; name="%s"; filename="%s"' % \
                 (field_name, filename),
              'Content-Type: %s' % content_type,
              'Content-Transfer-Encoding: binary',
              '',
              body,
            ]
            for field_name, filename, content_type, body in self.files
            )
        
        # Flatten the list and add closing boundary marker,
        # then return CR+LF separated data
        flattened = list(itertools.chain(*parts))
        flattened.append('--' + self.boundary + '--')
        flattened.append('')
        return '\r\n'.join(flattened)

class TopException(Exception):
    #===========================================================================
    # 业务异常类
    #===========================================================================
    def __init__(self):
        self.errcode = None
        self.errmsg = None
        self.application_host = None
        self.service_host = None
    
    def __str__(self, *args, **kwargs):
        sb = "errcode=" + mixStr(self.errcode) +\
            " errmsg=" + mixStr(self.errmsg) +\
            " application_host=" + mixStr(self.application_host) +\
            " service_host=" + mixStr(self.service_host)
        return sb
       
class RequestException(Exception):
    #===========================================================================
    # 请求连接异常类
    #===========================================================================
    pass

class RestApi(object):
    #===========================================================================
    # Rest api的基类
    #===========================================================================
    
    def __init__(self, url=None):
        #=======================================================================
        # 初始化基类
        # Args @param domain: 请求的域名或者ip
        #      @param port: 请求的端口
        #=======================================================================
        if(url == None):
            raise RequestException("domain must not be empty.")
        if(url.find('http://') >= 0):
            self.__port = 80
            pathUrl = url.replace('http://','')
        elif(url.find('https://') >= 0):
            self.__port = 443
            pathUrl = url.replace('https://','')
        else:
            raise RequestException("http protocol is not validate.")
        
        index = pathUrl.find('/')
        if(index > 0):
            self.__domain = pathUrl[0:index]
            self.__path = pathUrl[index:]
        else:
            self.__domain = pathUrl
            self.__path = ''

        # print("domain:" + self.__domain + ",path:" + self.__path + ",port:" + str(self.__port))
        
    def get_request_header(self):
        return {
            'Content-type': 'application/json;charset=UTF-8',
            "Cache-Control": "no-cache",
            "Connection": "Keep-Alive",
        }

    def getHttpMethod(self):
        return "GET"
        
    def getapiname(self):
        return ""
    
    def getMultipartParas(self):
        return [];

    def getTranslateParas(self):
        return {};
    
    def _check_requst(self):
        pass
    
    def getResponse(self, authrize='',accessKey='',accessSecret='',suiteTicket='',corpId='', timeout=30):
        #=======================================================================
        # 获取response结果
        #=======================================================================
        if(self.__port == 443):
            connection = http.client.HTTPSConnection(self.__domain, self.__port, None, None, timeout)
        else:
            connection = http.client.HTTPConnection(self.__domain, self.__port, timeout)
        sys_parameters = {
            P_PARTNER_ID: SYSTEM_GENERATE_VERSION,
        }
        if authrize is not None:
            sys_parameters[P_ACCESS_TOKEN] = authrize
        application_parameter = self.getApplicationParameters()
        sign_parameter = sys_parameters.copy()
        sign_parameter.update(application_parameter)
        
        header = self.get_request_header();
        if(self.getMultipartParas()):
            form = MultiPartForm()
            for key, value in list(application_parameter.items()):
                form.add_field(key, value)
            for key in self.getMultipartParas():
                fileitem = getattr(self,key)
                if(fileitem and isinstance(fileitem,FileItem)):
                    form.add_file(key,fileitem.filename,fileitem.content)
            body = str(form)
            header['Content-type'] = form.get_content_type()
        else:
            body = urllib.parse.urlencode(application_parameter)
        
        if(accessKey != ''):
            timestamp = str(int(round(time.time()))) + '000'
            print(("timestamp:" + timestamp))
            canonicalString = self.getCanonicalStringForIsv(timestamp, suiteTicket)
            print(("canonicalString:" + canonicalString))
            print(("accessSecret:" + accessSecret))
            signature = self.computeSignature(accessSecret, canonicalString)
            print(("signature:" + signature))
            ps = {}
            ps["accessKey"] = accessKey
            ps["signature"] = signature
            ps["timestamp"] = timestamp
            if(suiteTicket != ''):
                ps["suiteTicket"] = suiteTicket
            if(corpId != ''):
                ps["corpId"] = corpId
            queryStr = urllib.parse.urlencode(ps)
            if (self.__path.find("?") > 0):
                fullPath = self.__path + "&" + queryStr
            else:
                fullPath = self.__path + "?" + queryStr
            print(("fullPath:" + fullPath))
        else:
            if (self.__path.find("?") > 0):
                fullPath = (self.__path + "&access_token=" + str(authrize)) if len(str(authrize)) > 0 else self.__path
            else:
                fullPath = (self.__path + "?access_token=" + str(authrize)) if len(str(authrize)) > 0 else self.__path

        if(self.getHttpMethod() == "GET"):
            if (fullPath.find("?") > 0):
                fullPath = fullPath + "&" + body;
            else:
                fullPath = fullPath + "?" + body
            connection.request(self.getHttpMethod(), fullPath, headers=header)
        else:
            if (self.getMultipartParas()):
                body = body
            else:
                body = json.dumps(application_parameter)
            connection.request(self.getHttpMethod(), fullPath, body=body, headers=header)
        response = connection.getresponse();
        if response.status is not 200:
            raise RequestException('invalid http status ' + str(response.status) + ',detail body:' + response.read())
        result = response.read()
        # print("result:" + result)
        jsonobj = json.loads(result)
        if P_CODE in jsonobj and jsonobj[P_CODE] != 0:
            error = TopException()
            error.errcode = jsonobj[P_CODE]
            error.errmsg = jsonobj[P_MSG]
            error.application_host = response.getheader("Application-Host", "")
            error.service_host = response.getheader("Location-Host", "")
            raise error
        return jsonobj
    
    def getCanonicalStringForIsv(self, timestamp, suiteTicket):
        if(suiteTicket != ''):
            return timestamp + '\n' + suiteTicket
        else:
            return timestamp

    def computeSignature(self, secret, canonicalString):
        message = canonicalString.encode(encoding="utf-8")
        sec = secret.encode(encoding="utf-8")
        return str(base64.b64encode(hmac.new(sec, message, digestmod=hashlib.sha256).digest()))
    
    def getApplicationParameters(self):
        application_parameter = {}
        for key, value in self.__dict__.items():
            if not key.startswith("__") and not key in self.getMultipartParas() and not key.startswith("_RestApi__") and value is not None :
                if(key.startswith("_")):
                    application_parameter[key[1:]] = value
                else:
                    application_parameter[key] = value
        #查询翻译字典来规避一些关键字属性
        translate_parameter = self.getTranslateParas()
        for key, value in application_parameter.items():
            if key in translate_parameter:
                application_parameter[translate_parameter[key]] = application_parameter[key]
                del application_parameter[key]
        return application_parameter



'''
Created by auto_sdk on 2019.11.18
'''
from dingtalk.api.base import RestApi
class OapiDingCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.attachment = None
		self.creator_userid = None
		self.receiver_userids = None
		self.remind_time = None
		self.remind_type = None
		self.text_content = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.ding.create'



'''
Created by auto_sdk on 2020.08.05
'''
from dingtalk.api.base import RestApi
class OapiAiMtTranslateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.query = None
		self.source_language = None
		self.target_language = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.ai.mt.translate'



'''
Created by auto_sdk on 2024.06.17
'''
from dingtalk.api.base import RestApi
class OapiV2DepartmentCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.auto_approve_apply = None
		self.brief = None
		self.code = None
		self.create_dept_group = None
		self.dept_permits = None
		self.emp_apply_join_dept = None
		self.extension = None
		self.hide_dept = None
		self.hide_scene_config = None
		self.name = None
		self.order = None
		self.outer_dept = None
		self.outer_dept_only_self = None
		self.outer_permit_depts = None
		self.outer_permit_users = None
		self.outer_scene_config = None
		self.parent_id = None
		self.source_identifier = None
		self.telephone = None
		self.user_permits = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.v2.department.create'



'''
Created by auto_sdk on 2021.02.23
'''
from dingtalk.api.base import RestApi
class OapiWorkspaceProjectMemberRemoveRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.operator_staff_id = None
		self.project_source_id = None
		self.source = None
		self.staff_id = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.workspace.project.member.remove'



'''
Created by auto_sdk on 2023.06.14
'''
from dingtalk.api.base import RestApi
class OapiCrmObjectdataCustomerQueryRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.current_operator_userid = None
		self.cursor = None
		self.page_size = None
		self.query_dsl = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.crm.objectdata.customer.query'



'''
Created by auto_sdk on 2021.10.27
'''
from dingtalk.api.base import RestApi
class OapiSmartworkHrmMasterCheckRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.biz_uk = None
		self.entity_code = None
		self.scope_code = None
		self.tenant_id = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.smartwork.hrm.master.check'



'''
Created by auto_sdk on 2021.01.26
'''
from dingtalk.api.base import RestApi
class OapiCalendarListRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.calendar_folder_id = None
		self.max_results = None
		self.page_token = None
		self.single_events = None
		self.time_max = None
		self.time_min = None
		self.user_id = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.calendar.list'



'''
Created by auto_sdk on 2021.03.26
'''
from dingtalk.api.base import RestApi
class OapiPlanetomFeedsCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.anchor_id = None
		self.appoint_begin_time = None
		self.cover_url = None
		self.feed_type = None
		self.group_id_type = None
		self.group_ids = None
		self.introduction = None
		self.open_app_id = None
		self.pic_introduction_url = None
		self.pre_video_url = None
		self.title = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.planetom.feeds.create'



'''
Created by auto_sdk on 2019.12.04
'''
from dingtalk.api.base import RestApi
class OapiImChatServicegroupNoticeCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.chat_id = None
		self.send_ding = None
		self.sticky = None
		self.text_content = None
		self.title = None
		self.unique_key = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.im.chat.servicegroup.notice.create'



'''
Created by auto_sdk on 2020.04.28
'''
from dingtalk.api.base import RestApi
class OapiEduHomeworkStudentCommentCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.attributes = None
		self.biz_code = None
		self.class_id = None
		self.comment = None
		self.hw_id = None
		self.media = None
		self.photo = None
		self.student_id = None
		self.student_name = None
		self.teacher_userid = None
		self.video = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.edu.homework.student.comment.create'



'''
Created by auto_sdk on 2021.01.21
'''
from dingtalk.api.base import RestApi
class OapiSceneservicegroupMessageSendRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.at_dingtalkids = None
		self.at_mobiles = None
		self.at_unionids = None
		self.bizid = None
		self.btn_orientation = None
		self.btns = None
		self.content = None
		self.is_at_all = None
		self.message_type = None
		self.open_conversationid = None
		self.receiver_dingtalkids = None
		self.receiver_mobiles = None
		self.receiver_unionids = None
		self.title = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.sceneservicegroup.message.send'



'''
Created by auto_sdk on 2020.05.26
'''
from dingtalk.api.base import RestApi
class OapiKacDatavMicroappDetailListRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.request = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.kac.datav.microapp.detail.list'



'''
Created by auto_sdk on 2021.03.03
'''
from dingtalk.api.base import RestApi
class OapiAttendanceApproveCancelRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.approve_id = None
		self.dingtalk_approve_id = None
		self.sub_type = None
		self.tag_name = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.attendance.approve.cancel'



'''
Created by auto_sdk on 2020.09.27
'''
from dingtalk.api.base import RestApi
class OapiCrmObjectdataContactQueryRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.current_operator_userid = None
		self.cursor = None
		self.page_size = None
		self.provider_corpid = None
		self.query_dsl = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.crm.objectdata.contact.query'



'''
Created by auto_sdk on 2020.10.14
'''
from dingtalk.api.base import RestApi
class OapiEduSubjectListRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.cursor = None
		self.data_order_type = None
		self.operator_userid = None
		self.period_code = None
		self.size = None
		self.sort_type = None
		self.subject_code_list = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.edu.subject.list'



'''
Created by auto_sdk on 2020.08.17
'''
from dingtalk.api.base import RestApi
class OapiCardIntelligentEmpgroupSendRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.msg_key = None
		self.param_json = None
		self.receiver_list = None
		self.uuid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.card.intelligent.empgroup.send'



'''
Created by auto_sdk on 2020.07.07
'''
from dingtalk.api.base import RestApi
class OapiServiceGetSuiteTokenRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.suite_key = None
		self.suite_secret = None
		self.suite_ticket = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.service.get_suite_token'



'''
Created by auto_sdk on 2022.04.25
'''
from dingtalk.api.base import RestApi
class OapiCrmGroupCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.colleague_userid_list = None
		self.contact_id_list = None
		self.customer_corpid = None
		self.customer_id = None
		self.group_owner = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.crm.group.create'



'''
Created by auto_sdk on 2021.05.20
'''
from dingtalk.api.base import RestApi
class OapiRetailUserUnionidqueryRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.channel = None
		self.outer_id = None
		self.sub_outer_id = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.retail.user.unionidquery'



'''
Created by auto_sdk on 2022.01.19
'''
from dingtalk.api.base import RestApi
class OapiWorkspaceProjectCreateV2Request(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.belong_corp_userid = None
		self.create_group = None
		self.desc = None
		self.logo_media_id = None
		self.name = None
		self.open_conversation_id = None
		self.outer_id = None
		self.type = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.workspace.project.create.v2'



'''
Created by auto_sdk on 2019.12.23
'''
from dingtalk.api.base import RestApi
class OapiPbpInstanceCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.active = None
		self.biz_id = None
		self.end_time = None
		self.outer_id = None
		self.start_time = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.pbp.instance.create'



'''
Created by auto_sdk on 2020.10.28
'''
from dingtalk.api.base import RestApi
class OapiWikiResourceAuthRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.agentid = None
		self.auth_code = None
		self.is_public = None
		self.resource_list = None
		self.resource_type = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.wiki.resource.auth'



'''
Created by auto_sdk on 2022.09.13
'''
from dingtalk.api.base import RestApi
class OapiFinanceLoanNotifyRepaymentRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.amount = None
		self.available_amount = None
		self.bank_name = None
		self.bankcard_no = None
		self.current_int_ovd_days = None
		self.current_ovd_terms = None
		self.current_paid_interest = None
		self.current_paid_penalty = None
		self.current_paid_principal = None
		self.current_paid_total_amount = None
		self.current_prin_ovd_days = None
		self.fail_reason = None
		self.fail_reason_to_user = None
		self.id_card_no = None
		self.loan_order_no = None
		self.open_channel_name = None
		self.open_product_code = None
		self.open_product_name = None
		self.open_product_type = None
		self.paid_interest = None
		self.paid_penalty = None
		self.paid_principal = None
		self.paid_total_amount = None
		self.payable_interest = None
		self.payable_penalty = None
		self.payable_principal = None
		self.payable_total_amount = None
		self.period_paid_all = None
		self.period_paid_interest = None
		self.period_paid_penalty = None
		self.period_paid_principal = None
		self.period_paid_total_amount = None
		self.period_payable_interest = None
		self.period_payable_penalty = None
		self.period_payable_principal = None
		self.period_payable_total_amount = None
		self.repay_real_date = None
		self.repay_type = None
		self.repayment_no = None
		self.repayment_terms = None
		self.status = None
		self.type = None
		self.user_mobile = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.finance.loan.notify.repayment'



'''
Created by auto_sdk on 2019.09.25
'''
from dingtalk.api.base import RestApi
class OapiAttendanceApproveDurationCalculateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.biz_type = None
		self.calculate_model = None
		self.duration_unit = None
		self.from_time = None
		self.to_time = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.attendance.approve.duration.calculate'



'''
Created by auto_sdk on 2022.09.23
'''
from dingtalk.api.base import RestApi
class OapiReportListRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.cursor = None
		self.end_time = None
		self.modified_end_time = None
		self.modified_start_time = None
		self.size = None
		self.start_time = None
		self.template_name = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.report.list'



'''
Created by auto_sdk on 2020.11.03
'''
from dingtalk.api.base import RestApi
class OapiEduHomeworkCommentTipsCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.attributes = None
		self.audio = None
		self.biz_code = None
		self.content = None
		self.media = None
		self.photo = None
		self.sort_order = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.edu.homework.comment.tips.create'



'''
Created by auto_sdk on 2020.03.06
'''
from dingtalk.api.base import RestApi
class OapiRhinoHumanresProductionteamQueryRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.query_production_team_param = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.rhino.humanres.productionteam.query'



'''
Created by auto_sdk on 2025.03.31
'''
from dingtalk.api.base import RestApi
class OapiDingmiGroupGetRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.conversation_id = None
		self.date = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.dingmi.group.get'



'''
Created by auto_sdk on 2020.01.09
'''
from dingtalk.api.base import RestApi
class OapiWorkspaceProjectCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.belong_corp_userid = None
		self.create_group = None
		self.desc = None
		self.name = None
		self.open_conversation_id = None
		self.outer_id = None
		self.template_id = None
		self.type = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.workspace.project.create'



'''
Created by auto_sdk on 2019.07.01
'''
from dingtalk.api.base import RestApi
class OapiSmartdeviceFacegroupDeviceListRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.biz_id = None
		self.cursor = None
		self.mode = None
		self.size = None
		self.type = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.smartdevice.facegroup.device.list'



'''
Created by auto_sdk on 2018.07.25
'''
from dingtalk.api.base import RestApi
class OapiMediaUploadRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.media = None
		self.type = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.media.upload'

	def getMultipartParas(self):
		return ['media']



'''
Created by auto_sdk on 2023.05.19
'''
from dingtalk.api.base import RestApi
class OapiCrmContactCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.contact_name = None
		self.contact_phone = None
		self.contact_position_list = None
		self.creator_userid = None
		self.customer_instance_id = None
		self.provider_corpid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.crm.contact.create'



'''
Created by auto_sdk on 2019.07.01
'''
from dingtalk.api.base import RestApi
class OapiDingpayBillBatchquerycountRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.apply_pay_operator_userid = None
		self.bill_category = None
		self.biz_code = None
		self.create_operator_userid = None
		self.extension = None
		self.gmt_apply_pay_begin_time = None
		self.gmt_apply_pay_end_time = None
		self.gmt_create_begin_time = None
		self.gmt_create_end_time = None
		self.gmt_pay_begin_time = None
		self.gmt_pay_end_time = None
		self.max_amount = None
		self.min_amount = None
		self.pay_channel_list = None
		self.pay_channel_payer_real_uid = None
		self.payee_id = None
		self.payee_user_type = None
		self.payer_id = None
		self.payer_user_type = None
		self.receiptor_type_list = None
		self.status_list = None
		self.termination_reason = None
		self.title = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.dingpay.bill.batchquerycount'



'''
Created by auto_sdk on 2019.07.01
'''
from dingtalk.api.base import RestApi
class OapiProcessQuerypayrelatedtemplateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.process.querypayrelatedtemplate'



'''
Created by auto_sdk on 2020.03.23
'''
from dingtalk.api.base import RestApi
class OapiRhinoMosExecClothesSynccreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.additional_operations = None
		self.auto_start = None
		self.biz_type = None
		self.clothes = None
		self.entity_type = None
		self.order_id = None
		self.source = None
		self.tenant_id = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.rhino.mos.exec.clothes.synccreate'



'''
Created by auto_sdk on 2021.01.19
'''
from dingtalk.api.base import RestApi
class OapiSmartworkHrmNavigationbarConfigGetRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.change_param = None
		self.type = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.smartwork.hrm.navigationbar.config.get'



'''
Created by auto_sdk on 2019.12.17
'''
from dingtalk.api.base import RestApi
class OapiDepartmentGetRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.id = None
		self.lang = None

	def getHttpMethod(self):
		return 'GET'

	def getapiname(self):
		return 'dingtalk.oapi.department.get'



'''
Created by auto_sdk on 2020.10.23
'''
from dingtalk.api.base import RestApi
class OapiUserUpdateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.department = None
		self.email = None
		self.extattr = None
		self.hiredDate = None
		self.isHide = None
		self.isSenior = None
		self.jobnumber = None
		self.lang = None
		self.managerUserid = None
		self.mobile = None
		self.name = None
		self.orderInDepts = None
		self.orgEmail = None
		self.position = None
		self.positionInDepts = None
		self.remark = None
		self.tel = None
		self.userid = None
		self.workPlace = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.user.update'



'''
Created by auto_sdk on 2019.07.01
'''
from dingtalk.api.base import RestApi
class OapiDingTaskStatusUpdateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.operator_userid = None
		self.task_id = None
		self.task_status = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.ding.task.status.update'



'''
Created by auto_sdk on 2021.03.29
'''
from dingtalk.api.base import RestApi
class OapiCustomerserviceSessionCloseRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.close_session = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.customerservice.session.close'



'''
Created by auto_sdk on 2022.08.10
'''
from dingtalk.api.base import RestApi
class OapiRhinoMosLayoutOperationdefsSectionfirstRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.flow_version = None
		self.need_assign_info = None
		self.order_id = None
		self.section_code = None
		self.tenant_id = None
		self.tmp_save = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.rhino.mos.layout.operationdefs.sectionfirst'



'''
Created by auto_sdk on 2019.08.01
'''
from dingtalk.api.base import RestApi
class OapiChatNickBatchupdateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.chatid = None
		self.user_nick_model = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.chat.nick.batchupdate'



'''
Created by auto_sdk on 2021.04.14
'''
from dingtalk.api.base import RestApi
class OapiEduCourseCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.biz_key = None
		self.end_time = None
		self.introduce = None
		self.name = None
		self.op_userid = None
		self.option = None
		self.start_time = None
		self.teacher_corpid = None
		self.teacher_userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.edu.course.create'



'''
Created by auto_sdk on 2022.12.20
'''
from dingtalk.api.base import RestApi
class OapiDingmiCommonLoginAccesstokenRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.foreign_id = None
		self.nick = None
		self.source = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.dingmi.common.login.accesstoken'



'''
Created by auto_sdk on 2021.04.13
'''
from dingtalk.api.base import RestApi
class OapiSceneservicegroupGroupCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.bizid = None
		self.group_name = None
		self.group_tag_names = None
		self.group_tagids = None
		self.member_staffids = None
		self.open_groupsetid = None
		self.open_teamid = None
		self.owner_staffId = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.sceneservicegroup.group.create'



'''
Created by auto_sdk on 2021.09.02
'''
from dingtalk.api.base import RestApi
class OapiWorkspaceProjectAssistantSendRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.action_url = None
		self.content = None
		self.pic_url = None
		self.reciever_userids = None
		self.style = None
		self.title = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.workspace.project.assistant.send'



'''
Created by auto_sdk on 2021.03.19
'''
from dingtalk.api.base import RestApi
class OapiSmartdeviceFacelevelGetRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.userid_list = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.smartdevice.facelevel.get'



'''
Created by auto_sdk on 2019.10.18
'''
from dingtalk.api.base import RestApi
class OapiRoleVisibleSetRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.role_id = None
		self.visible_role_ids = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.role.visible.set'



'''
Created by auto_sdk on 2021.03.29
'''
from dingtalk.api.base import RestApi
class OapiCustomerserviceMemberGetRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.ding_corp_id = None
		self.open_instance_id = None
		self.production_type = None
		self.third_tenant_id = None
		self.user_id = None
		self.user_source_id = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.customerservice.member.get'



'''
Created by auto_sdk on 2020.07.16
'''
from dingtalk.api.base import RestApi
class OapiRhinoMosExecTrackBindRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.entities = None
		self.entity_type = None
		self.order_id = None
		self.tenant_id = None
		self.track_id = None
		self.track_type = None
		self.userid = None
		self.workstation_code = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.rhino.mos.exec.track.bind'



'''
Created by auto_sdk on 2019.07.03
'''
from dingtalk.api.base import RestApi
class SmartworkBpmsProcessinstanceCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.agent_id = None
		self.approvers = None
		self.cc_list = None
		self.cc_position = None
		self.dept_id = None
		self.form_component_values = None
		self.originator_user_id = None
		self.process_code = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.smartwork.bpms.processinstance.create'



'''
Created by auto_sdk on 2022.01.19
'''
from dingtalk.api.base import RestApi
class OapiWorkspaceTaskMigrateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.agentid = None
		self.operator_userid = None
		self.task = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.workspace.task.migrate'



'''
Created by auto_sdk on 2022.12.30
'''
from dingtalk.api.base import RestApi
class OapiDingmiRobotPushRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.conversation_id = None
		self.msg_key = None
		self.msg_param = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.dingmi.robot.push'



'''
Created by auto_sdk on 2020.08.09
'''
from dingtalk.api.base import RestApi
class OapiAtsEvaluateJobmatchStartRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.biz_code = None
		self.candidate_id = None
		self.category = None
		self.ext_data = None
		self.invite_url = None
		self.job_id = None
		self.outer_evaluate_id = None
		self.result_url = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.ats.evaluate.jobmatch.start'



'''
Created by auto_sdk on 2020.12.04
'''
from dingtalk.api.base import RestApi
class OapiEduHomeworkCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.attributes = None
		self.biz_code = None
		self.course_name = None
		self.hw_content = None
		self.hw_deadline = None
		self.hw_deadline_open = None
		self.hw_media = None
		self.hw_photo = None
		self.hw_title = None
		self.hw_type = None
		self.hw_video = None
		self.identifier = None
		self.scheduled_release = None
		self.scheduled_time = None
		self.select_class = None
		self.select_stu = None
		self.status = None
		self.target_role = None
		self.teacher_name = None
		self.teacher_userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.edu.homework.create'



'''
Created by auto_sdk on 2019.07.03
'''
from dingtalk.api.base import RestApi
class IsvCallCalluserRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.authed_corp_id = None
		self.authed_staff_id = None
		self.staff_id = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.isv.call.calluser'



'''
Created by auto_sdk on 2019.07.03
'''
from dingtalk.api.base import RestApi
class SmartworkBpmsProcessinstanceListRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.cursor = None
		self.end_time = None
		self.process_code = None
		self.size = None
		self.start_time = None
		self.userid_list = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.smartwork.bpms.processinstance.list'



'''
Created by auto_sdk on 2024.09.12
'''
from dingtalk.api.base import RestApi
class OapiMessageMassSendRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.dep_id_list = None
		self.is_preview = None
		self.is_to_all = None
		self.media_id = None
		self.msg_body = None
		self.msg_type = None
		self.roleIds = None
		self.text_content = None
		self.unionid = None
		self.userid_list = None
		self.uuid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.message.mass.send'



'''
Created by auto_sdk on 2019.08.30
'''
from dingtalk.api.base import RestApi
class OapiAttendanceApproveCheckRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.approve_id = None
		self.jump_url = None
		self.punch_check_time = None
		self.punch_id = None
		self.tag_name = None
		self.user_check_time = None
		self.userid = None
		self.work_date = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.attendance.approve.check'



'''
Created by auto_sdk on 2022.03.02
'''
from dingtalk.api.base import RestApi
class OapiDingtaxUserPushRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.source_region = None
		self.user_info_list = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.dingtax.user.push'



'''
Created by auto_sdk on 2020.12.30
'''
from dingtalk.api.base import RestApi
class OapiMicroappCustomUpdateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.agent_id = None
		self.app_corp_id = None
		self.desc = None
		self.homepage_link = None
		self.icon = None
		self.ip_white_list = None
		self.name = None
		self.omp_link = None
		self.pc_homepage_link = None
		self.top_related_corp_id = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.microapp.custom.update'



'''
Created by auto_sdk on 2020.08.10
'''
from dingtalk.api.base import RestApi
class OapiAtsEvaluateJobmatchFinishRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.biz_code = None
		self.conclusion = None
		self.ext_data = None
		self.outer_evaluate_id = None
		self.report_download_url = None
		self.result = None
		self.score = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.ats.evaluate.jobmatch.finish'



'''
Created by auto_sdk on 2022.05.17
'''
from dingtalk.api.base import RestApi
class OapiSmartworkHrmEmployeeV2ListRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.agentid = None
		self.field_filter_list = None
		self.userid_list = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.smartwork.hrm.employee.v2.list'



'''
Created by auto_sdk on 2018.07.25
'''
from dingtalk.api.base import RestApi
class OapiCallBackRegisterCallBackRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.aes_key = None
		self.call_back_tag = None
		self.token = None
		self.url = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.call_back.register_call_back'



'''
Created by auto_sdk on 2021.04.25
'''
from dingtalk.api.base import RestApi
class OapiAttendanceVacationRecordListRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.leave_code = None
		self.offset = None
		self.op_userid = None
		self.size = None
		self.userids = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.attendance.vacation.record.list'



'''
Created by auto_sdk on 2021.01.26
'''
from dingtalk.api.base import RestApi
class OapiFinanceFaceVerificationUpdateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.business_id = None
		self.fail_reason = None
		self.id_card_no = None
		self.request_code = None
		self.result_code = None
		self.user_mobile = None
		self.verify_result = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.finance.faceVerification.update'



'''
Created by auto_sdk on 2019.07.03
'''
from dingtalk.api.base import RestApi
class OapiHrmEmployeeUpdateresumerecordRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.content = None
		self.k_v_content = None
		self.pc_url = None
		self.phone_url = None
		self.record_timestamp = None
		self.resume_id = None
		self.title = None
		self.userid = None
		self.web_url = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.hrm.employee.updateresumerecord'



'''
Created by auto_sdk on 2020.09.21
'''
from dingtalk.api.base import RestApi
class CorpConversationCorpconversionListmemberRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.count = None
		self.offset = None
		self.open_conversation_id = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.corp.conversation.corpconversion.listmember'



'''
Created on 2018-9-17

@author: xiaoxuan.lp
'''
from dingtalk.api.base import sign



class appinfo(object):
    def __init__(self,appkey,secret):
        self.appkey = appkey
        self.secret = secret
        
def getDefaultAppInfo():
    pass

     
def setDefaultAppInfo(appkey,secret):
    default = appinfo(appkey,secret)
    global getDefaultAppInfo 
    getDefaultAppInfo = lambda: default
    




    




'''
Created by auto_sdk on 2020.11.03
'''
from dingtalk.api.base import RestApi
class OapiEduHomeworkStudentMarkTagRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.biz_code = None
		self.class_id = None
		self.hw_id = None
		self.student_id = None
		self.student_name = None
		self.tag = None
		self.teacher_id = None
		self.text = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.edu.homework.student.mark.tag'



'''
Created by auto_sdk on 2021.06.10
'''
from dingtalk.api.base import RestApi
class OapiEduCourseListRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.course_codes = None
		self.cursor = None
		self.end_time = None
		self.name = None
		self.op_userid = None
		self.option = None
		self.participant_condition = None
		self.scene = None
		self.size = None
		self.start_time = None
		self.statuses = None
		self.suite_keys = None
		self.teacher_conditions = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.edu.course.list'



'''
Created by auto_sdk on 2020.10.26
'''
from dingtalk.api.base import RestApi
class OapiLiveGroupliveSharelistRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.cid = None
		self.live_uuid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.live.grouplive.sharelist'



'''
Created by auto_sdk on 2021.02.19
'''
from dingtalk.api.base import RestApi
class OapiSmartworkHrmOrganizationDeptGetRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.dept_id = None
		self.field_code_list = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.smartwork.hrm.organization.dept.get'



'''
Created by auto_sdk on 2020.11.02
'''
from dingtalk.api.base import RestApi
class OapiImpaasConversationCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.channel = None
		self.name = None
		self.owner_userid = None
		self.userid_list = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.impaas.conversation.create'



'''
Created by auto_sdk on 2022.09.16
'''
from dingtalk.api.base import RestApi
class OapiEduUserListRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.class_id = None
		self.page_no = None
		self.page_size = None
		self.role = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.edu.user.list'



'''
Created by auto_sdk on 2024.03.12
'''
from dingtalk.api.base import RestApi
class OapiProcessPrintTemplateSaveRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.attributes = None
		self.font = None
		self.open_customize_print = None
		self.process_code = None
		self.vm = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.process.print.template.save'



'''
Created by auto_sdk on 2025.03.12
'''
from dingtalk.api.base import RestApi
class OapiV2UserUpdateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.avatarMediaId = None
		self.dept_id_list = None
		self.dept_name = None
		self.dept_order_list = None
		self.dept_position_list = None
		self.dept_title_list = None
		self.email = None
		self.exclusive_mobile = None
		self.exclusive_mobile_verify_status = None
		self.ext_attrs = None
		self.ext_attrs_update_mode = None
		self.extension = None
		self.extension_i18n = None
		self.flower_name = None
		self.force_update_fields = None
		self.gender = None
		self.has_subordinate = None
		self.hide_mobile = None
		self.hired_date = None
		self.init_password = None
		self.job_number = None
		self.language = None
		self.limited = None
		self.loginId = None
		self.manager_userid = None
		self.mobile = None
		self.name = None
		self.nickname = None
		self.org_email = None
		self.org_email_type = None
		self.remark = None
		self.senior_mode = None
		self.telephone = None
		self.title = None
		self.userid = None
		self.work_place = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.v2.user.update'



'''
Created by auto_sdk on 2019.12.16
'''
from dingtalk.api.base import RestApi
class OapiMessageSendToConversationRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.action_card = None
		self.cid = None
		self.file = None
		self.image = None
		self.link = None
		self.markdown = None
		self.msg = None
		self.msgtype = None
		self.oa = None
		self.sender = None
		self.text = None
		self.voice = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.message.send_to_conversation'



'''
Created by auto_sdk on 2025.01.08
'''
from dingtalk.api.base import RestApi
class OapiRobotMessageSendorggroupRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.chatbot_id = None
		self.msg_key = None
		self.msg_param = None
		self.open_conversation_id = None
		self.token = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.robot.message.sendorggroup'



'''
Created by auto_sdk on 2020.10.27
'''
from dingtalk.api.base import RestApi
class OapiAtsMessageSystemaccountSendmessageRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.content = None
		self.message_biz_code = None
		self.openid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.ats.message.systemaccount.sendmessage'



'''
Created by auto_sdk on 2021.01.27
'''
from dingtalk.api.base import RestApi
class OapiSceneservicegroupGroupsetCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.group_templateid = None
		self.groupset_name = None
		self.open_teamid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.sceneservicegroup.groupset.create'



'''
Created by auto_sdk on 2018.07.25
'''
from dingtalk.api.base import RestApi
class OapiCallBackGetCallBackFailedResultRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)

	def getHttpMethod(self):
		return 'GET'

	def getapiname(self):
		return 'dingtalk.oapi.call_back.get_call_back_failed_result'



'''
Created by auto_sdk on 2021.01.29
'''
from dingtalk.api.base import RestApi
class OapiEduGuardianGetRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.class_id = None
		self.guardian_userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.edu.guardian.get'



'''
Created by auto_sdk on 2021.11.22
'''
from dingtalk.api.base import RestApi
class OapiImChatScencegroupMessageSendV2Request(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.at_mobiles = None
		self.at_union_ids = None
		self.at_users = None
		self.is_at_all = None
		self.msg_media_id_param_map = None
		self.msg_param_map = None
		self.msg_template_id = None
		self.receiver_mobiles = None
		self.receiver_union_ids = None
		self.receiver_user_ids = None
		self.robot_code = None
		self.target_open_conversation_id = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.im.chat.scencegroup.message.send_v2'



'''
Created by auto_sdk on 2021.08.09
'''
from dingtalk.api.base import RestApi
class OapiCspaceGrantCustomSpaceRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.agent_id = None
		self.domain = None
		self.duration = None
		self.fileids = None
		self.path = None
		self.type = None
		self.userid = None

	def getHttpMethod(self):
		return 'GET'

	def getapiname(self):
		return 'dingtalk.oapi.cspace.grant_custom_space'



'''
Created by auto_sdk on 2021.05.27
'''
from dingtalk.api.base import RestApi
class OapiPlanetomFeedsWatchdataGetRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.anchor_id = None
		self.chat_id = None
		self.feed_id = None
		self.index = None
		self.page_size = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.planetom.feeds.watchdata.get'



'''
Created by auto_sdk on 2020.07.28
'''
from dingtalk.api.base import RestApi
class OapiAttendanceListRecordRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.checkDateFrom = None
		self.checkDateTo = None
		self.isI18n = None
		self.userIds = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.attendance.listRecord'



'''
Created by auto_sdk on 2020.10.09
'''
from dingtalk.api.base import RestApi
class OapiCrmObjectdataContactDeleteRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.data_id = None
		self.operator_userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.crm.objectdata.contact.delete'



'''
Created by auto_sdk on 2020.11.23
'''
from dingtalk.api.base import RestApi
class OapiEduFeedSyncRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.album_id = None
		self.dept_id = None
		self.fee_type = None
		self.feed_medias = None
		self.future = None
		self.media_uid = None
		self.op_userId = None
		self.send_time = None
		self.send_uid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.edu.feed.sync'



'''
Created by auto_sdk on 2018.07.25
'''
from dingtalk.api.base import RestApi
class OapiSnsGetuserinfoRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.sns_token = None

	def getHttpMethod(self):
		return 'GET'

	def getapiname(self):
		return 'dingtalk.oapi.sns.getuserinfo'



'''
Created by auto_sdk on 2021.08.17
'''
from dingtalk.api.base import RestApi
class OapiMpdevPreviewbuildCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.build_script_version = None
		self.channel = None
		self.corpid = None
		self.enable_tabbar = None
		self.ignore_http_req_permission = None
		self.ignore_webview_domain_check = None
		self.is_remote_debug = None
		self.is_remote_x = None
		self.main_page = None
		self.miniapp_id = None
		self.package_key = None
		self.page = None
		self.plugin_package_key = None
		self.plugin_refs = None
		self.query = None
		self.sub_packages = None
		self.tyroid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.mpdev.previewbuild.create'



'''
Created by auto_sdk on 2020.12.22
'''
from dingtalk.api.base import RestApi
class OapiEduMainDataGetRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.stat_date = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.edu.main.data.get'



'''
Created by auto_sdk on 2023.02.26
'''
from dingtalk.api.base import RestApi
class OapiImChatScenegroupCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.add_friend_forbidden = None
		self.all_members_can_create_calendar = None
		self.all_members_can_create_mcs_conf = None
		self.chat_banned_type = None
		self.group_email_disabled = None
		self.group_live_switch = None
		self.icon = None
		self.management_type = None
		self.members_to_admin_chat = None
		self.mention_all_authority = None
		self.only_admin_can_ding = None
		self.only_admin_can_set_msg_top = None
		self.owner_user_id = None
		self.searchable = None
		self.show_history_type = None
		self.subadmin_ids = None
		self.template_id = None
		self.title = None
		self.user_ids = None
		self.uuid = None
		self.validation_type = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.im.chat.scenegroup.create'



'''
Created by auto_sdk on 2018.07.25
'''
from dingtalk.api.base import RestApi
class OapiFileUploadTransactionRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.agent_id = None
		self.chunk_numbers = None
		self.file_size = None
		self.upload_id = None

	def getHttpMethod(self):
		return 'GET'

	def getapiname(self):
		return 'dingtalk.oapi.file.upload.transaction'



'''
Created by auto_sdk on 2024.06.12
'''
from dingtalk.api.base import RestApi
class OapiImChatScencegroupFileDownloadurlGetRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.download_code = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.im.chat.scencegroup.file.downloadurl.get'



'''
Created by auto_sdk on 2021.01.11
'''
from dingtalk.api.base import RestApi
class OapiImChatScencegroupInteractivecardSendRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.card_mediaid_param_map = None
		self.card_param_map = None
		self.card_template_id = None
		self.out_track_id = None
		self.receiver_userid_list = None
		self.robot_code = None
		self.target_open_conversation_id = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.im.chat.scencegroup.interactivecard.send'



'''
Created by auto_sdk on 2023.08.07
'''
from dingtalk.api.base import RestApi
class OapiAttendanceRecordUploadRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.device_id = None
		self.device_name = None
		self.photo_url = None
		self.user_check_time = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.attendance.record.upload'



'''
Created by auto_sdk on 2021.03.15
'''
from dingtalk.api.base import RestApi
class OapiMessageCorpconversationSendbytemplateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.agent_id = None
		self.data = None
		self.dept_id_list = None
		self.template_id = None
		self.userid_list = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.message.corpconversation.sendbytemplate'



'''
Created by auto_sdk on 2021.08.09
'''
from dingtalk.api.base import RestApi
class OapiProjectPointAddRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.action_time = None
		self.rule_code = None
		self.rule_name = None
		self.score = None
		self.tenant_id = None
		self.userid = None
		self.uuid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.project.point.add'



'''
Created by auto_sdk on 2021.03.16
'''
from dingtalk.api.base import RestApi
class OapiAppstoreInternalOrderGetRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.biz_order_id = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.appstore.internal.order.get'



'''
Created by auto_sdk on 2021.05.26
'''
from dingtalk.api.base import RestApi
class OapiRobotSendRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.actionCard = None
		self.at = None
		self.feedCard = None
		self.link = None
		self.markdown = None
		self.msgtype = None
		self.text = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.robot.send'



'''
Created by auto_sdk on 2021.06.23
'''
from dingtalk.api.base import RestApi
class OapiImChatScencegroupInteractivecardCallbackRegisterRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.api_secret = None
		self.callbackRouteKey = None
		self.callback_url = None
		self.forceUpdate = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.im.chat.scencegroup.interactivecard.callback.register'



'''
Created by auto_sdk on 2019.08.23
'''
from dingtalk.api.base import RestApi
class OapiEduCardTaskSubmitRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.card_type = None
		self.content = None
		self.metering_number = None
		self.user_card_task_id = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.edu.card.task.submit'



'''
Created by auto_sdk on 2020.03.10
'''
from dingtalk.api.base import RestApi
class OapiEnterpriseSubareaTotaldataStatRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.corp_id = None
		self.order_by = None
		self.page_size = None
		self.page_start = None
		self.return_fields = None
		self.stat_date = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.enterprise.subarea.totaldata.stat'



'''
Created by auto_sdk on 2020.11.18
'''
from dingtalk.api.base import RestApi
class OapiCspaceFilePresignedurlGetRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.dentryid = None
		self.expire_seconds = None
		self.inner_invoke = None
		self.spaceid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.cspace.file.presignedurl.get'



'''
Created by auto_sdk on 2020.11.30
'''
from dingtalk.api.base import RestApi
class OapiAlitripBtripProjectModifyRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.request = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.alitrip.btrip.project.modify'



'''
Created by auto_sdk on 2021.12.24
'''
from dingtalk.api.base import RestApi
class OapiKacDatavAnnualReportGetRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.dept_id = None
		self.type = None
		self.user_id = None
		self.year = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.kac.datav.annual_report.get'



'''
Created by auto_sdk on 2018.07.25
'''
from dingtalk.api.base import RestApi
class OapiMicroappRuleDeleteRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.agentId = None
		self.ruleId = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.microapp.rule.delete'



'''
Created by auto_sdk on 2022.02.25
'''
from dingtalk.api.base import RestApi
class OapiAttendanceScheduleListbyusersRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.from_date_time = None
		self.op_user_id = None
		self.to_date_time = None
		self.userids = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.attendance.schedule.listbyusers'
